@@ -45,6 +45,13 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         m.itemset(shp, 1)
         return MVPolyCube(m, **kwd)
 
+    @classmethod
+    def zero(self, **kwd) :
+        """
+        Return the zero polynomial.
+        """
+        return MVPolyCube(**kwd)
+
     def dtype_set_callback(self, value) :
         """
         For internal use. Sets the datatype of the 
@@ -133,9 +140,13 @@ class MVPolyCube(mvpoly.base.MVPoly) :
     def order(self) :
         """
         Return the maximal order of each of the variables of
-        the polynomial as a tuple of integers
+        the polynomial as a tuple of integers. For the zero 
+        polynomial, returns the empty tuple.
         """
-        return tuple(n-1 for n in self.coef.shape) 
+        if self.coef.any() :
+            return tuple(n-1 for n in self.coef.shape) 
+        else :
+            return ()
 
     def homdeg(self) :
         """
@@ -143,7 +154,10 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         monomial degrees of monomials with nonzero coefficients. 
         """
         nzis = np.nonzero(self.coef)
-        return np.max([sum(t) for t in zip(*nzis)])
+        degs = [sum(t) for t in zip(*nzis)]
+        if not degs :
+            raise ValueError("homogeneous degree undefined for zero polynomial")
+        return np.max(degs)
 
     def eval(self, *args) :
         """
@@ -169,10 +183,10 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         dims = self.coef.shape
         N = len(dims)
 
-        assert N == len(args), \
-            "wrong number of args (%i) for a %i-variable polynomial" % \
-            (len(args), N)
-
+        if N != len(args) :
+            msg = "wrong number of args (%i) for a %i-variable polynomial" % \
+                (len(args), N)
+            raise(ValueError, msg)
         C = self.coef.flat
 
         # generate list-of-list of powers of monomials
