@@ -55,8 +55,8 @@ class TestMVPolyCubeDtype(unittest.TestCase) :
 class TestMVPolyCubeOrder(unittest.TestCase) :
 
     def test_order_zero(self) :
-        p = MVPolyCube([0])
-        expected = (0,)
+        p = MVPolyCube.zero()
+        expected = ()
         obtained = p.order()
         self.assertTrue(expected == obtained,
                         "bad order:\n%s" % repr(obtained))
@@ -96,7 +96,7 @@ class TestMVPolyCubeEqual(unittest.TestCase) :
         p = MVPolyCube([1, 2, 3])
         q = MVPolyCube([1, 2, 3, 4])
         self.assertFalse(p == q, "bad equality")
-        self.assertTrue(p != q, "bad equality")
+        self.assertTrue(p != q, "bad non-equality")
 
 
 class TestMVPolyCubeAdd(unittest.TestCase) :
@@ -425,19 +425,23 @@ class TestMVPolyCubeInt(unittest.TestCase) :
                         "bad 1D indefinite integral \n%s\n%s" % \
                             (repr(obtained.coef), repr(expected.coef)))
 
-    def test_int_2d(self) :
+    def test_int_2d_x(self) :
         x, y = MVPolyCube.monomials(2, dtype = np.double)
         p = 3*x**2 + 4*x*y + 3*y**2
-        expected = (x**3 + 2*y*(x**2) + 3*x*y**2).coef 
-        obtained = p.int(1, 0).coef
-        self.assertTrue((expected == obtained).all(),
+        expected = x**3 + 2*y*(x**2) + 3*x*y**2
+        obtained = p.int(1, 0)
+        self.assertTrue(expected == obtained,
                         "bad indefinite integral (x) \n%s\n%s" % \
-                            (repr(obtained), repr(expected)))
-        expected = (3*y*x**2 + 2*x*y**2 + y**3).coef
-        obtained = p.int(0, 1).coef
-        self.assertTrue((expected == obtained).all(),
+                            (repr(obtained.coef), repr(expected.coef)))
+
+    def test_int_2d_y(self) :
+        x, y = MVPolyCube.monomials(2, dtype = np.double)
+        p = 3*x**2 + 4*x*y + 3*y**2
+        expected = 3*y*x**2 + 2*x*y**2 + y**3
+        obtained = p.int(0, 1)
+        self.assertTrue(expected == obtained,
                         "bad indefinite integral (y) \n%s\n%s" % \
-                            (repr(obtained), repr(expected)))
+                            (repr(obtained.coef), repr(expected.coef)))
 
     def test_int_dtype(self) :
         for dt in [np.float32, np.float64, np.complex] :
@@ -525,6 +529,10 @@ class TestMVPolyCubeCompose(unittest.TestCase) :
 
 class TestMVPolyCubeHomdeg(unittest.TestCase) :
 
+    def test_homdeg_zero(self) :
+        p = MVPolyCube.zero(dtype=int)
+        self.assertRaises(ValueError, p.homdeg) 
+
     def test_homdeg_1d(self) :
         x, = MVPolyCube.monomials(1, dtype=int)
         p = x**5 + x + 3
